@@ -56,6 +56,7 @@
 #include "semanage_core_process.h"
 #include "semanage_core_login_process.h"
 #include "semanage_core_fcontext_process.h"
+#include "semanage_core_port_process.h"
 #include "mainwindow.h"
 
 MainWindow::MainWindow(QWidget *parent, const char *name)
@@ -92,6 +93,7 @@ MainWindow::MainWindow(QWidget *parent, const char *name)
 	semanage_core_process_o = 0;
 	semanage_core_login_process_o = 0;
 	semanage_core_fcontext_process_o = 0;
+	semanage_core_port_process_o = 0;
 
 	//connect SIGNAL to objects    
 
@@ -107,7 +109,7 @@ MainWindow::MainWindow(QWidget *parent, const char *name)
 	createToolBars();
 	createStatusBar();
 
-	setCaption(tr("segatex-4.40"));
+	setCaption(tr("segatex-4.50"));
 	setIcon(QPixmap::fromMimeSource("icon.png"));
 }
 
@@ -421,6 +423,11 @@ void MainWindow::createActions()
 	semanage_core_fcontext_processAct->setStatusTip(tr("Semanage fcontext -a -m -d."));
 	connect(semanage_core_fcontext_processAct, SIGNAL(activated()), this, SLOT(semanage_core_fcontext_process()));
 	connect(semanage_core_fcontext_processAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+
+	semanage_core_port_processAct = new QAction(tr("&semanage port"), 0, this);
+	semanage_core_port_processAct->setStatusTip(tr("Semanage port -a -m -d."));
+	connect(semanage_core_port_processAct, SIGNAL(activated()), this, SLOT(semanage_core_port_process()));
+	connect(semanage_core_port_processAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 }
 
 void MainWindow::createMenus()
@@ -498,6 +505,7 @@ void MainWindow::createMenus()
 	semanage_core_processAct->addTo(semanageMenu);
 	semanage_core_login_processAct->addTo(semanageMenu);
 	semanage_core_fcontext_processAct->addTo(semanageMenu);
+	semanage_core_port_processAct->addTo(semanageMenu);
 
 	menuBar()->insertItem(tr("&File"), fileMenu);
 	menuBar()->insertItem(tr("&Edit"), editMenu);
@@ -849,7 +857,7 @@ void MainWindow::notice()
 void MainWindow::about()
 {
 	QMessageBox::about(this, tr("About segatex"),
-		tr("<h2>segatex-4.40</h2>"
+		tr("<h2>segatex-4.50</h2>"
 		"<p>Copyright &copy; 2007"
 		"<p>Shintaro Fujiwara."
 		"<p>segatex_suite is a SELinux tool"
@@ -1055,3 +1063,12 @@ void MainWindow::semanage_core_fcontext_process()
 	semanage_core_fcontext_process_o->raise();
 	semanage_core_fcontext_process_o->setActiveWindow();
 }
+void MainWindow::semanage_core_port_process()
+{
+	if(!semanage_core_port_process_o) {
+		semanage_core_port_process_o = new SemanageCorePortProcess(this);
+	}
+	semanage_core_port_process_o->show();
+	semanage_core_port_process_o->raise();
+	semanage_core_port_process_o->setActiveWindow();
+}
