@@ -53,6 +53,7 @@ class SemoduleCoreProcess;
 class SemanageCoreProcess;
 class SemanageCoreLoginProcess;
 class SemanageCoreFcontextProcess;
+class SemanageCorePortProcess;
 
 class MainWindow : public QMainWindow
 {
@@ -104,6 +105,7 @@ private slots:
     void semanage_core_process();
     void semanage_core_login_process();
     void semanage_core_fcontext_process();
+    void semanage_core_port_process();
 
     void save();
     void saveAs();
@@ -169,6 +171,7 @@ private:
     SemanageCoreProcess *semanage_core_process_o;
     SemanageCoreLoginProcess *semanage_core_login_process_o;
     SemanageCoreFcontextProcess *semanage_core_fcontext_process_o;
+    SemanageCorePortProcess *semanage_core_port_process_o;
     
     QPopupMenu *fileMenu;
     QPopupMenu *editMenu;
@@ -236,6 +239,7 @@ private:
     QAction *semanage_core_processAct;
     QAction *semanage_core_login_processAct;
     QAction *semanage_core_fcontext_processAct;
+    QAction *semanage_core_port_processAct;
 };
 
 #endif
